==> jc-1.4.0.tar.gz: soot/jimple/internal/JInstanceOfExpr.h <==
// public class soot.jimple.internal.JInstanceOfExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4522a9ddedb3d65f soot_jimple_internal_AbstractInstanceOfExpr
// @dep_class f46872b2da6bcb67 soot_jimple_internal_JInstanceOfExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInstanceOfExpr

#include "soot/jimple/internal/AbstractInstanceOfExpr.h"

#ifndef _JC_soot_jimple_internal_JInstanceOfExpr_H_
#define _JC_soot_jimple_internal_JInstanceOfExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JInstanceOfExpr$sub_refs	_jc_soot_jimple_internal_JInstanceOfExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JInstanceOfExpr$sub_nonrefs	_jc_soot_jimple_internal_JInstanceOfExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JInstanceOfExpr$refs	_jc_soot_jimple_internal_JInstanceOfExpr$refs;
typedef struct _jc_soot_jimple_internal_JInstanceOfExpr$nonrefs	_jc_soot_jimple_internal_JInstanceOfExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JInstanceOfExpr$object	_jc_soot_jimple_internal_JInstanceOfExpr$object;

typedef const struct _jc_soot_jimple_internal_JInstanceOfExpr$vmethods	_jc_soot_jimple_internal_JInstanceOfExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JInstanceOfExpr$vtable	_jc_soot_jimple_internal_JInstanceOfExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JInstanceOfExpr$vtype	_jc_soot_jimple_internal_JInstanceOfExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JInstanceOfExpr$method$_init$743c179cbcd16e16(_jc_env *, struct _jc_soot_jimple_internal_JInstanceOfExpr$object *, struct _jc_object *, struct _jc_soot_Type$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JInstanceOfExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JInstanceOfExpr$object *);
extern void _jc_soot_jimple_internal_JInstanceOfExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_JInstanceOfExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JInstanceOfExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JInstanceOfExpr$method_info$convertToBaf$0357e46cf55b475a;

// Virtual methods structure
struct _jc_soot_jimple_internal_JInstanceOfExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JInstanceOfExpr$object *);
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_JInstanceOfExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_JInstanceOfExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInstanceOfExpr$vmethods	soot_jimple_internal_AbstractInstanceOfExpr;
	_jc_soot_jimple_internal_JInstanceOfExpr$vmethods	soot_jimple_internal_JInstanceOfExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JInstanceOfExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JInstanceOfExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JInstanceOfExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JInstanceOfExpr$refs {
    _jc_soot_jimple_internal_JInstanceOfExpr$sub_refs	soot_jimple_internal_JInstanceOfExpr;
    _jc_soot_jimple_internal_AbstractInstanceOfExpr$sub_refs	soot_jimple_internal_AbstractInstanceOfExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JInstanceOfExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JInstanceOfExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInstanceOfExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceOfExpr;
    _jc_soot_jimple_internal_JInstanceOfExpr$sub_nonrefs	soot_jimple_internal_JInstanceOfExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JInstanceOfExpr$object {
	_jc_soot_jimple_internal_JInstanceOfExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JInstanceOfExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JInstanceOfExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JInstanceOfExpr$vtype _jc_soot_jimple_internal_JInstanceOfExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JInstanceOfExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JInstanceOfExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JInstanceOfExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JInstanceOfExpr.h <==
// public class soot.jimple.internal.JInstanceOfExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4522a9ddedb3d65f soot_jimple_internal_AbstractInstanceOfExpr
// @dep_class f46872b2da6bcb67 soot_jimple_internal_JInstanceOfExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInstanceOfExpr

#include "soot/jimple/internal/AbstractInstanceOfExpr.h"

#ifndef _JC_soot_jimple_internal_JInstanceOfExpr_H_
#define _JC_soot_jimple_internal_JInstanceOfExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JInstanceOfExpr$sub_refs	_jc_soot_jimple_internal_JInstanceOfExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JInstanceOfExpr$sub_nonrefs	_jc_soot_jimple_internal_JInstanceOfExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JInstanceOfExpr$refs	_jc_soot_jimple_internal_JInstanceOfExpr$refs;
typedef struct _jc_soot_jimple_internal_JInstanceOfExpr$nonrefs	_jc_soot_jimple_internal_JInstanceOfExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JInstanceOfExpr$object	_jc_soot_jimple_internal_JInstanceOfExpr$object;

typedef const struct _jc_soot_jimple_internal_JInstanceOfExpr$vmethods	_jc_soot_jimple_internal_JInstanceOfExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JInstanceOfExpr$vtable	_jc_soot_jimple_internal_JInstanceOfExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JInstanceOfExpr$vtype	_jc_soot_jimple_internal_JInstanceOfExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JInstanceOfExpr$method$_init$743c179cbcd16e16(_jc_env *, struct _jc_soot_jimple_internal_JInstanceOfExpr$object *, struct _jc_object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JInstanceOfExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JInstanceOfExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JInstanceOfExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_JInstanceOfExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JInstanceOfExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JInstanceOfExpr$method_info$convertToBaf$0357e46cf55b475a;

// Virtual methods structure
struct _jc_soot_jimple_internal_JInstanceOfExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JInstanceOfExpr$object *) _JC_JCNI_ATTR;
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_JInstanceOfExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JInstanceOfExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInstanceOfExpr$vmethods	soot_jimple_internal_AbstractInstanceOfExpr;
	_jc_soot_jimple_internal_JInstanceOfExpr$vmethods	soot_jimple_internal_JInstanceOfExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JInstanceOfExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JInstanceOfExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JInstanceOfExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JInstanceOfExpr$refs {
    _jc_soot_jimple_internal_JInstanceOfExpr$sub_refs	soot_jimple_internal_JInstanceOfExpr;
    _jc_soot_jimple_internal_AbstractInstanceOfExpr$sub_refs	soot_jimple_internal_AbstractInstanceOfExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JInstanceOfExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JInstanceOfExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInstanceOfExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceOfExpr;
    _jc_soot_jimple_internal_JInstanceOfExpr$sub_nonrefs	soot_jimple_internal_JInstanceOfExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JInstanceOfExpr$object {
	_jc_soot_jimple_internal_JInstanceOfExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JInstanceOfExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JInstanceOfExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JInstanceOfExpr$vtype _jc_soot_jimple_internal_JInstanceOfExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JInstanceOfExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JInstanceOfExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JInstanceOfExpr_H_ */
